@@ -16,4 +16,8 @@ def plot():
 
 def test():
     assert_equality(plot, "test_fillstyle_reference.tex")
-    return
+
+
+if __name__ == "__main__":
+    plot()
+    plt.show()
