@@ -1,3 +1,5 @@
+import pathlib
+
 import matplotlib.pyplot as plt
 
 # the picture 'lena.png' with origin='lower' is flipped upside-down.
@@ -5,13 +7,11 @@ import matplotlib.pyplot as plt
 
 
 def plot():
-    import os
-
     import matplotlib.image as mpimg
     from matplotlib import rcParams
 
-    this_dir = os.path.dirname(os.path.realpath(__file__))
-    img = mpimg.imread(os.path.join(this_dir, "lena.png"))
+    this_dir = pathlib.Path(__file__).resolve().parent
+    img = mpimg.imread(this_dir / "lena.png")
 
     dpi = rcParams["figure.dpi"]
     figsize = img.shape[0] / dpi, img.shape[1] / dpi
