@@ -2,15 +2,15 @@ from helpers import assert_equality
 
 
 def plot():
-    import numpy as np
-    import matplotlib.pyplot as plt
     import matplotlib.cm as cm
+    import matplotlib.pyplot as plt
+    import numpy as np
 
     x, y = np.meshgrid(np.linspace(0, 1), np.linspace(0, 1))
     z = x ** 2 - y ** 2
 
     fig = plt.figure()
-    plt.pcolormesh(x, y, z, cmap=cm.viridis)
+    plt.pcolormesh(x, y, z, cmap=cm.viridis, shading="gouraud")
     # plt.colorbar()
 
     return fig
